package SPVM::Regex::Opcode;

1;

=head1 NAME

SPVM::Regex::Opcode - Regular expression pattern

=head1 SYNOPSYS
  
  use Regex::Opcode;

=head1 DESCRIPTION

L<Regex::Opcode|SPVM::Regex::Opcode> is a internal data structure which represents regular expression patterns for L<Regex|SPVM::Regex>.
